# -*- coding: utf-8 -*-

"""Top-level package for PandasTools."""

from . import accessors

__author__ = """Philipp Temminghoff"""
__email__ = "phil65@kodi.tv"
__version__ = "0.5.5"

__all__ = ["accessors", "utils"]
